
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '35.8.2',
    'branch_nick': 'release-35-LTS',
    'revision_id': 'b97fb8ca1f696c470b1ccb0ce21a09361f989e46',
    'revno': 13210
}
